=============
Django Robots
=============

.. image:: https://jazzband.co/static/img/badge.svg
   :target: https://jazzband.co/
   :alt: Jazzband
.. image:: https://github.com/jazzband/django-robots/workflows/Test/badge.svg
   :target: https://github.com/jazzband/django-robots/actions
.. image:: https://codecov.io/gh/jazzband/django-robots/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/jazzband/django-robots
.. image:: https://img.shields.io/pypi/v/django-robots.svg
   :target: https://pypi.python.org/pypi/django-robots

This is a basic Django application to manage robots.txt files following the
`robots exclusion protocol`_, complementing the Django_ `Sitemap contrib app`_.

For installation instructions, see the documentation `install section`_;
for instructions on how to use this application, and on
what it provides, see the file "overview.txt" in the "docs/"
directory or on ReadTheDocs: https://django-robots.readthedocs.io/

Supported Django versions
-------------------------

* Django 4.0
* Django 3.2
* Django 3.1
* Django 2.2

For older Django versions (1.6-1.10) use ``django-robots==3.0``.
for Django 2 and above, use ``django-robots>=4.0.0``.

Supported Python version
------------------------

* Python 3.7, 3.8, 3.9, 3.10

.. _install section: https://django-robots.readthedocs.io/en/latest/#installation
.. _robots exclusion protocol: http://en.wikipedia.org/wiki/Robots_exclusion_standard
.. _Django: http://www.djangoproject.com/
.. _Sitemap contrib app: http://docs.djangoproject.com/en/dev/ref/contrib/sitemaps/
